'use strict';

var otherEntry = require('./generated-main.js');



exports.a = otherEntry.a;
exports.c = otherEntry.c;
